@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.75 2005/11/15 18:02:06 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.77 2006/01/10 18:00:13 richb Exp $
  *
- *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -244,7 +244,8 @@ enum button_flags {
     regrcl       = 8192,       /* Recall register */
     expnum       = 16384,      /* Exponential number */
     postfixop    = 32768,      /* Unary postfix operation */
-    prefixop     = 65536       /* Unary prefix operation */
+    prefixop     = 65536,      /* Unary prefix operation */
+    dpoint       = 131072      /* Decimal point */
 };
 
 struct exprm_state {       /* Expression mode state */
@@ -389,9 +390,12 @@ char *gc_strdup(char *str);
 const char *get_radix();
 char *get_resource(enum res_type);
 const char *get_tsep();
+char *make_fixed(int *, char *, int, int, int);
 char *make_number(int *, int, BOOLEAN);
 char *set_bool(int);
 
+char *get_localized_numeric_point(void);
+
 unsigned short *get_but_data();
 
 int button_mods(int);
